@@ -10,7 +10,7 @@ def RunTests( Number ):
     # use Linux as the default:
     SuccessCount = 0
     Platform = platform.platform()
-    Command = "LD_LIBRARY_PATH=../Weaver:../Experimental ./JobTests >/dev/null"
+    Command = "./Tests/ThreadWeaverJobTests >/dev/null"
 #    if re.search( "Darwin", Platform ):
 #        Command = "DYLD_LIBRARY_PATH=../Weaver:../Experimental ./JobTests.app/Contents/MacOs/JobTests >/dev/null"
     for count in range( Number ):
